@@ -10,7 +10,8 @@ from datetime import datetime
 
 def refresh_token(func):
     """
-    Decorator to refresh the currently issued token if
+    Decorator to refresh the token expiry of the currently issued token if a command is issued or reissue the token
+    if (20 minutes - delta) has been exceeded
     """
     @wraps(func)
     def wrapper(self, *args, **kwargs):
@@ -21,3 +22,14 @@ def refresh_token(func):
         return func(self, *args, **kwargs)
 
     return wrapper
+
+
+def initialisable(func):
+    """
+    Initialises a pre-defined web service if its client instance is non-existent
+    """
+    @wraps(func)
+    def wrapper(self, *args, **kwargs):
+
+        return func(self, *args, **kwargs)
+    return wrapper
